@@ -19,6 +19,7 @@ from horizon import exceptions
 from horizon import tabs
 
 from tacker_horizon.openstack_dashboard import api
+from tacker_horizon.openstack_dashboard.dashboards.nfv import utils  # noqa
 from tacker_horizon.openstack_dashboard.dashboards.nfv.vim import tables
 
 
@@ -76,7 +77,44 @@ class VIMTab(tabs.TableTab):
             return []
 
 
+class VIMEventsTab(tabs.TableTab):
+    name = _("Events Tab")
+    slug = "events_tab"
+    table_classes = (utils.EventsTable,)
+    template_name = ("horizon/common/_detail_table.html")
+    preload = False
+
+    def has_more_data(self, table):
+        return self._has_more
+
+    def get_events_data(self):
+        try:
+            self._has_more = True
+            utils.EventItemList.clear_list()
+            events = api.tacker.events_list(self.request,
+                                            self.tab_group.kwargs['vim_id'])
+            for event in events:
+                evt_obj = utils.EventItem(
+                    event['id'], event['resource_state'],
+                    event['event_type'],
+                    event['timestamp'],
+                    event['event_details'])
+                utils.EventItemList.add_item(evt_obj)
+            return utils.EventItemList.EVTLIST_P
+        except Exception as e:
+            self._has_more = False
+            error_message = _('Unable to get events %s') % e
+            exceptions.handle(self.request, error_message)
+            return []
+
+
 class VIMTabs(tabs.TabGroup):
     slug = "vim_tabs"
     tabs = (VIMTab,)
     sticky = True
+
+
+class VIMDetailsTabs(tabs.TabGroup):
+    slug = "VIM_details"
+    tabs = (VIMEventsTab,)
+    sticky = True
