@@ -23,7 +23,11 @@ from tacker_horizon.openstack_dashboard import api
 
 
 class OnBoardVNF(forms.SelfHandlingForm):
-    name = forms.CharField(max_length=80, label=_("Name"), required=False)
+    name = forms.CharField(max_length=255, label=_("Name"))
+    description = forms.CharField(widget=forms.widgets.Textarea(
+                                  attrs={'rows': 4}),
+                                  label=_("Description"),
+                                  required=False)
     source_type = forms.ChoiceField(
         label=_('TOSCA Template Source'),
         required=False,
@@ -65,6 +69,11 @@ class OnBoardVNF(forms.SelfHandlingForm):
         if not toscal_raw and not toscal_file:
             raise ValidationError(
                 _("No input was provided for the namespace content."))
+
+        if toscal_file and not toscal_file.name.endswith(('.yaml', '.csar')):
+            raise ValidationError(_("Only .yaml or .csar file uploads \
+                                    are supported"))
+
         try:
             if toscal_file:
                 toscal_str = self.files['toscal_file'].read()
@@ -82,8 +91,10 @@ class OnBoardVNF(forms.SelfHandlingForm):
         try:
             toscal = data['tosca']
             vnfd_name = data['name']
-            tosca_arg = {'vnfd': {'name': vnfd_name, 'attributes': {'vnfd':
-                                                                    toscal}}}
+            vnfd_description = data['description']
+            tosca_arg = {'vnfd': {'name': vnfd_name,
+                                  'description': vnfd_description,
+                                  'attributes': {'vnfd': toscal}}}
             vnfd_instance = api.tacker.create_vnfd(request, tosca_arg)
             messages.success(request,
                              _('VNF Catalog entry %s has been created.') %
